//定义游戏场景元素的Id
var game_stage_dom_id = "game-stage";

//-------------------------------------------------------------------------
/**
 * 初始化小游戏场景
 * @auhor lx
 * @param void
 */
function initGameStage(){
    //获取宽高和比例
    var height = api.winHeight/3;
    var scale = height / 400;
    var stageWidth = 1200 * scale;

    //重新设置游戏场景的高度
    $api.attr($api.byId(game_stage_dom_id), "height", height);
    
    //初始化PIXI
    var renderer = PIXI.autoDetectRenderer(api.winWidth, height,{backgroundColor : 0x1099bb});
    document.getElementById(game_stage_dom_id).appendChild(renderer.view);
    var stage = new PIXI.Container();

    //异步载入游戏资源
    var loader = PIXI.loader;
    loader.add('layer0',"../image/layer0.png");
    loader.add('layer1',"../image/layer1.png");
    loader.add('layer2',"../image/layer2.png");
    loader.add('layer3',"../image/layer3.png");
    for (var i=1; i<=6; i++){
        for (var j=1; j<=5; j++){
            loader.add('role' + i + '_' + j, "../image/role_" + i + '/role_' + i + '_' + j + ".png");
        }
    }

    //定义载入完成后的回调函数
    loader.once('complete',onAssetsLoaded);

    //开始载入
    loader.load();

    //总层数
    var layerCnt = 4;

    //背景层数组
    var sprLayers = [];

    //每个层的移动速度和方向
    var layerSpeed = [0, -0.1, 0.04, 0.16]

    //角色数组
    var roles = [];

    //资源载入完成以后的回调函数
    function onAssetsLoaded()
    {
        //无缝拼接每个背景层
        for (var i=0; i<layerCnt; ++i){
            var sprImg = 'layer' + i;

            var sprite1 = PIXI.Sprite.fromFrame(sprImg);
            var sprite2 = PIXI.Sprite.fromFrame(sprImg);

            sprLayers[i] = {sprite1:sprite1, sprite2:sprite2};

            stage.addChild(sprite1);
            stage.addChild(sprite2);

            sprite1.scale.set(scale);
            sprite2.scale.set(scale);

            if (layerSpeed[i]>0){
                sprite1.position.set(0,0);
                sprite2.position.set(stageWidth, 0);
            }else{
                sprite1.position.set(0,0);
                sprite2.position.set(-stageWidth, 0);
            }
        }


        //初始化动画角色
        for (var k=1; k<=6; k++){
            var frames = [];
            for (var i = 1; i <= 5; i++) {
                frames.push(PIXI.Texture.fromFrame('role' + k + '_' + i));
            }

            var role = new PIXI.extras.MovieClip(frames);
            roles.push(role);
            role.scale.set(scale);

            //天上飞的
            if (k==6){
                role.position.set(5.3*api.winWidth/7, 40);
            }
            //老司机
            else if (k==5){
                role.position.set(5.5*api.winWidth/7, height*0.6);
            }
            //其他普通角色
            else{
                role.position.set(k*api.winWidth/7, height*0.6);
            }

            role.anchor.set(0.5);
            role.animationSpeed = 0.2;
            role.play();

            stage.addChild(role);
        }

        //开始循环动画
        animate();
    }

    //pixi的动画循环函数
    function animate() {
        requestAnimationFrame(animate);

        for (var i=1; i<layerCnt; ++i) {
            //速度
            if (layerSpeed[i] > 0){
                sprLayers[i].sprite1.position.set(sprLayers[i].sprite1.x - layerSpeed[i], 0);
                if (sprLayers[i].sprite1.x < -sprLayers[i].sprite1.width) {
                    sprLayers[i].sprite1.position.set(sprLayers[i].sprite2.x + sprLayers[i].sprite2.width - 1, 0);
                }

                sprLayers[i].sprite2.position.set(sprLayers[i].sprite2.x - layerSpeed[i], 0);
                if (sprLayers[i].sprite2.x < -sprLayers[i].sprite2.width) {
                    sprLayers[i].sprite2.position.set(sprLayers[i].sprite1.x + sprLayers[i].sprite1.width - 1, 0);
                }
            }

            //速度小于0 反向
            else {
                sprLayers[i].sprite1.position.set(sprLayers[i].sprite1.x - layerSpeed[i], 0);
                if (sprLayers[i].sprite1.x > sprLayers[i].sprite1.width) {
                    sprLayers[i].sprite1.position.set(sprLayers[i].sprite2.x - sprLayers[i].sprite2.width + 1, 0);
                }

                sprLayers[i].sprite2.position.set(sprLayers[i].sprite2.x - layerSpeed[i], 0);
                if (sprLayers[i].sprite2.x > sprLayers[i].sprite2.width) {
                    sprLayers[i].sprite2.position.set(sprLayers[i].sprite1.x - sprLayers[i].sprite1.width + 1, 0);
                }
            }
        }

        renderer.render(stage);
    }
}