//字数统计函数,按一次触发一次,要把可输入状态下的字数统计时就截取的字符串位置数定义在外面,apiready里面在触发调用时也不行
var title_length = "18",
    content_length = "150";

//---------------------------------------------------------------------
//初始化
apiready = function() {
    initTopicCache();

    //字数统计
    limitTopicTitleLength();
    limitTopicContentLength();

    //发送按钮状态
    checkSendBtnState();
    //监听发送话题事件
    onSendTopic();
}

//---------------------------------------------------------------------
/**
 * 话题初始化缓存
 * @author:hj
 */
function initTopicCache() {
    if (localStorage.getItem("user-topic-title")) {
        var title = localStorage.getItem("user-topic-title");
        $api.val($api.dom('#topic-input'), title);
        //第一次进入时输入框会自动获得焦点,这时没有输入致截取的长度不对
        title_length = title.length;
    }
    if (localStorage.getItem("user-topic-content")) {
        var content = localStorage.getItem("user-topic-content");
        $api.val($api.dom('#topic-content-input'), content);
        content_length = content.length;
        //这里不用sendBtnState()到这里确定话题内容都有值,改变按钮颜色
        $api.css($api.dom('#send-btn'), 'color:#fff;');
    }
}

//---------------------------------------------------------------------
/**
 * 话题标题输入框字数控制
 * @author:hj
 */
function limitTopicTitleLength() {
    var title = $api.val($api.dom('#topic-input'));
    var len = convertStrLen(title);
    if (len > 18) {
        api.toast({ msg: '您输入的字已经超过18个字了！', duration: 2000, location: 'middle' });
        $api.val($api.dom("#topic-input"), title.substr(0, title_length));
        $api.html($api.dom('#topic-title-num'), 18 + '/18');
    } else {
        localStorage.setItem("user-topic-title", title);
        console.log("输入:"+localStorage.getItem("user-topic-title"));
        title_length = title.length;
        $api.html($api.dom('#topic-title-num'), len + '/18');
    }
    checkSendBtnState();
}

//-----------------------------------------------------------------------
/**
 * 话题内容输入框字数控制
 * @author:hj
 */
function limitTopicContentLength(){
    var content = $api.val($api.dom('#topic-content-input'));
    var len = convertStrLen(content);
    if (len > 150) {
        api.toast({ msg: '您输入的字已经超过150个字了！', duration: 2000, location: 'middle' });
        $api.val($api.dom("#topic-content-input"), content.substr(0, content_length));
        $api.html($api.dom('#topic-content-num'), 150 + '/150');
    } else {
        localStorage.setItem("user-topic-content", content);
        console.log("输入:"+localStorage.getItem("user-topic-content"));
        content_length = content.length;
        $api.html($api.dom('#topic-content-num'), len + '/150');
    }
    checkSendBtnState();
}

//-----------------------------------------------------------------------
/**
 * 发送按钮是否可以操作的状态 必须话题和内容都有值
 * @author:hj
 */
function checkSendBtnState() {
    var title = $api.val($api.dom('#topic-input'));
    if ($api.trim(title) == "") {
        api.toast({ msg: '请输入话题', duration: 2000, location: 'middle' });
        $api.css($api.dom('#send-btn'), 'color:#9fa0a2;');
        return false;
    }
    var content = $api.val($api.dom('#topic-content-input'));
    if ($api.trim(content) == "") {
        api.toast({ msg: '请输入内容', duration: 2000, location: 'middle' });
        $api.css($api.dom('#send-btn'), 'color:#9fa0a2;');
        return false;
    }
    $api.css($api.dom('#send-btn'), 'color:#fff;');
}

//--------------------------------------------------------------------
/**
 * 监听发送话题点击事件 判断时间间隔
 * @author:hj
 */
function onSendTopic() {
    $api.addEvt($api.dom("#send-btn"), 'click', function() {
        if(checkSendBtnState() == false) {
            return false;
        }
        var time=(Date.parse(new Date())/1000);
        var timeInterval=localStorage.getItem("topicTimeInterval");
        if((time-timeInterval)<10) {
            api.toast({ msg: '每隔10秒可发布一个话题', duration: 2000, location: 'middle' });
            //console.log("时间"+timeInterval+" "+time);
            return false;
        }
        sendTopic();
    });
}

//------------------------------------------------------------------------
/**
 * 发表话题
 * @author:hj
 */
function sendTopic(){
    var data = {
        "nickname": localStorage.getItem("user-nickname"),
        "headimg": localStorage.getItem("user-headimg"),
        "title": $api.val($api.dom('#topic-input')),
        "content": $api.val($api.dom('#topic-content-input')),
        "user_id": localStorage.getItem("user-id")
    };
    api.ajax({
        url: config.dev_url + 'topic/create',
        method: 'post',
        data: {
            values: data
        },
        dataType: 'json'
    }, function(ret, err) {
        if (ret.status == 0) {
            openIndex();
            $api.val($api.dom("#topic-input"), "");
            $api.val($api.dom("#topic-content-input"), "");
            localStorage.setItem("topicTimeInterval",(Date.parse(new Date())/1000));
        } else {
            api.toast({ msg: '话题发布失败。', duration: 2000, location: 'middle' });
            console.log(config.dev_url+"topic/create "+JSON.stringify(data));
            console.log(JSON.stringify(err));
        }
    });
}

//---------------------------------------------------------------------
/**
 * 发布完成打开首页
 * @author:hj
 */
function openIndex() {
    api.openWin({
        name: 'index',
        url: '../../html/index_wrap.html',
        pageParam: {
            topic: 'release'
        },
        bounces: false,
        opaque: false,
        showProgress: true,
        vScrollBarEnabled: false,
        hScrollBarEnabled: false,
        slidBackEnabled: false,
        reload: true,
        delay: 300,
        animation: { duration: 400 }
    });
}